==> jc-1.4.0.tar.gz: javax/swing/event/CaretEvent.h <==
// public abstract class javax.swing.event.CaretEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 8a4c0fc94cfde406 javax_swing_event_CaretEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_CaretEvent_H_
#define _JC_javax_swing_event_CaretEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_swing_event_CaretEvent$sub_refs	_jc_javax_swing_event_CaretEvent$sub_refs;
typedef struct _jc_javax_swing_event_CaretEvent$sub_nonrefs	_jc_javax_swing_event_CaretEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_CaretEvent$refs	_jc_javax_swing_event_CaretEvent$refs;
typedef struct _jc_javax_swing_event_CaretEvent$nonrefs	_jc_javax_swing_event_CaretEvent$nonrefs;
typedef struct _jc_javax_swing_event_CaretEvent$object	_jc_javax_swing_event_CaretEvent$object;

typedef const struct _jc_javax_swing_event_CaretEvent$vmethods	_jc_javax_swing_event_CaretEvent$vmethods;
typedef const struct _jc_javax_swing_event_CaretEvent$vtable	_jc_javax_swing_event_CaretEvent$vtable;
typedef const struct _jc_javax_swing_event_CaretEvent$vtype	_jc_javax_swing_event_CaretEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_CaretEvent$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_javax_swing_event_CaretEvent$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jint _jc_javax_swing_event_CaretEvent$method$getDot$9fbe3db537d7ba75(_jc_env *, struct _jc_javax_swing_event_CaretEvent$object *);
extern jint _jc_javax_swing_event_CaretEvent$method$getMark$df26d5c2ab61c356(_jc_env *, struct _jc_javax_swing_event_CaretEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_CaretEvent$method_info$getDot$9fbe3db537d7ba75;
extern _jc_method _jc_javax_swing_event_CaretEvent$method_info$getMark$df26d5c2ab61c356;

// Virtual methods structure
struct _jc_javax_swing_event_CaretEvent$vmethods {
	jint	(*getDot$9fbe3db537d7ba75)(_jc_env *, struct _jc_javax_swing_event_CaretEvent$object *);
	jint	(*getMark$df26d5c2ab61c356)(_jc_env *, struct _jc_javax_swing_event_CaretEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_CaretEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_CaretEvent$vmethods	javax_swing_event_CaretEvent;
};

// Vtype
struct _jc_javax_swing_event_CaretEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_CaretEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_CaretEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_CaretEvent$refs {
    _jc_javax_swing_event_CaretEvent$sub_refs	javax_swing_event_CaretEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_CaretEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_CaretEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_CaretEvent$sub_nonrefs	javax_swing_event_CaretEvent;
};

// Object instance structure
struct _jc_javax_swing_event_CaretEvent$object {
	_jc_javax_swing_event_CaretEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_CaretEvent$vtype	*vtype;
	_jc_javax_swing_event_CaretEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_CaretEvent$vtype _jc_javax_swing_event_CaretEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_CaretEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_CaretEvent$class_object;

#endif	/* _JC_javax_swing_event_CaretEvent_H_ */

==> jc-1.4.6.tar.gz: javax/swing/event/CaretEvent.h <==
// public abstract class javax.swing.event.CaretEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 8a4c0fc94cfde406 javax_swing_event_CaretEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_CaretEvent_H_
#define _JC_javax_swing_event_CaretEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_swing_event_CaretEvent$sub_refs	_jc_javax_swing_event_CaretEvent$sub_refs;
typedef struct _jc_javax_swing_event_CaretEvent$sub_nonrefs	_jc_javax_swing_event_CaretEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_CaretEvent$refs	_jc_javax_swing_event_CaretEvent$refs;
typedef struct _jc_javax_swing_event_CaretEvent$nonrefs	_jc_javax_swing_event_CaretEvent$nonrefs;
typedef struct _jc_javax_swing_event_CaretEvent$object	_jc_javax_swing_event_CaretEvent$object;

typedef const struct _jc_javax_swing_event_CaretEvent$vmethods	_jc_javax_swing_event_CaretEvent$vmethods;
typedef const struct _jc_javax_swing_event_CaretEvent$vtable	_jc_javax_swing_event_CaretEvent$vtable;
typedef const struct _jc_javax_swing_event_CaretEvent$vtype	_jc_javax_swing_event_CaretEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_CaretEvent$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_javax_swing_event_CaretEvent$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_event_CaretEvent$method$getDot$9fbe3db537d7ba75(_jc_env *, struct _jc_javax_swing_event_CaretEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_event_CaretEvent$method$getMark$df26d5c2ab61c356(_jc_env *, struct _jc_javax_swing_event_CaretEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_CaretEvent$method_info$getDot$9fbe3db537d7ba75;
extern _jc_method _jc_javax_swing_event_CaretEvent$method_info$getMark$df26d5c2ab61c356;

// Virtual methods structure
struct _jc_javax_swing_event_CaretEvent$vmethods {
	jint	(*getDot$9fbe3db537d7ba75)(_jc_env *, struct _jc_javax_swing_event_CaretEvent$object *) _JC_JCNI_ATTR;
	jint	(*getMark$df26d5c2ab61c356)(_jc_env *, struct _jc_javax_swing_event_CaretEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_CaretEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_CaretEvent$vmethods	javax_swing_event_CaretEvent;
};

// Vtype
struct _jc_javax_swing_event_CaretEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_CaretEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_CaretEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_CaretEvent$refs {
    _jc_javax_swing_event_CaretEvent$sub_refs	javax_swing_event_CaretEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_CaretEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_CaretEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_CaretEvent$sub_nonrefs	javax_swing_event_CaretEvent;
};

// Object instance structure
struct _jc_javax_swing_event_CaretEvent$object {
	_jc_javax_swing_event_CaretEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_CaretEvent$vtype	*vtype;
	_jc_javax_swing_event_CaretEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_CaretEvent$vtype _jc_javax_swing_event_CaretEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_CaretEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_CaretEvent$class_object;

#endif	/* _JC_javax_swing_event_CaretEvent_H_ */
